spawn

Function spawn 

pub fn spawn(fut: impl SpawnFuture<()>)
Run a future to completion and throw its result away.

This is the imperative counterpart of use_future: start something from an event handler and report back with a Dispatch, which is Send and requests a repaint.

spawn(async move { dispatch.send(41) });